/*****************************************************************************/
/* zip.h								     */
/*****************************************************************************/

#ifndef	__ZIP_H_INCLUDED
#define	__ZIP_H_INCLUDED	1

#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include <stdarg.h>

/* Currently, these are defined during compilation:	*/
/*	#define	ENABLE_BZ2				*/
/*	#define	ENABLE_GZ				*/

#ifdef	ENABLE_BZ2
#include <bzlib.h>
#endif

#ifdef	ENABLE_GZ
#include <zlib.h>
#endif

#include <fits/fits.h>
#include "zip.h"

/*****************************************************************************/

#define	COMPRESS_NONE		0

#ifdef	ENABLE_BZ2
#define	COMPRESS_BZ2		1
#endif

#ifdef	ENABLE_GZ
#define	COMPRESS_GZ		2
#endif

/* struct compressinfo:
   An internal set of compressing/decompressing callbacks for various 
   compression/decompression algorithms.				     */
typedef struct
 {	int	type;
	char	*name;
	char * 	(*version)(void);
	int	(*compress)(char *,int,char *,int *,void *);
	int	(*decompress)(char *,int,char *,int *);
 } compressinfo;

/*****************************************************************************/

typedef struct
 {	int	nquantizebit;
	int	is_round;
 } compresstune;

/*****************************************************************************/

typedef struct
 {	int	dummy;
 } compressnone;

char *	fizip_none_version(void);
int	fizip_none_compress(char *in,int insize,char *out,int *outsize,void *param);
int	fizip_none_decompress(char *in,int insize,char *out,int *outsize);

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifdef	ENABLE_BZ2

typedef struct
 {	int	blocksize;
	int	workfactor;
 } compressbz2;

char *	fizip_bz2_version(void);
int	fizip_bz2_compress(char *in,int insize,char *out,int *outsize,void *param);
int	fizip_bz2_decompress(char *in,int insize,char *out,int *outsize);

#endif

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifdef	ENABLE_GZ

typedef struct
 {	int	compression;
 } compressgz;

char *	fizip_gz_version(void);
int	fizip_gz_compress(char *in,int insize,char *out,int *outsize,void *param);
int	fizip_gz_decompress(char *in,int insize,char *out,int *outsize);

#endif

/*****************************************************************************/

#define		FIZIP_ERR_INTERNAL			-1
#define		FIZIP_OK				0
#define		FIZIP_ERR_ALREADY_COMPRESSED		1
#define		FIZIP_ERR_UNIMPLEMENTED_METHOD		2
#define		FIZIP_ERR_UNSUPPORTED_EXTENSION		3
#define		FIZIP_ERR_UNEXPECTED_EOF		4
#define		FIZIP_ERR_COMPRESS			5
#define		FIZIP_ERR_DECOMPRESS			6
#define		FIZIP_ERR_CONFLICTING_HEADERS		7
#define		FIZIP_ERR_NOT_COMPRESSED		8

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

compressinfo * fizip_get_compressinfo(int method);
compressinfo * fizip_get_compressinfo_byname(char *name);

/*****************************************************************************/

int fizip_compress(int (*cb_read )(void *,void *,int),void *rdprm,
		   int (*cb_write)(void *,void *,int),void *wrprm,
		   int method,void *param,compresstune *ct);

int fizip_decompress(int (*cb_read )(void *,void *,int),void *rdprm,
		     int (*cb_write)(void *,void *,int),void *wrprm);

/*****************************************************************************/

#endif

/*****************************************************************************/
                            
